@@ -26,13 +26,10 @@ import datetime
 import platform
 
 import facct.config as config
+from facct.IncomeStatement import IncomeStatement
+from facct.IncomeStatement import get_float
 from facct.i18n import _
 
-def get_float(str):
-    if not str: return decimal.Decimal(0)
-    if not type(str) == type(''): return str
-    return decimal.Decimal(str.replace(',', '.'))
-
 debug = False
 epsilon = 0
 
@@ -337,124 +334,6 @@ class BalanceSheet:
                 '%.2f' % round(self._liabilities[i][1],2),
                 self.get_prev_year(i, 'passif_val')])
 
-class IncomeStatement:
-    def __init__(self, balance):
-        self._bal = balance
-
-    def load_and_save_year(self):
-        def deb(a):
-            if not self._bal.read_bal_account(a)[CREDIT] and\
-                not self._bal.read_bal_account(a)[DEBIT]:
-                return 0
-            if self._bal.read_bal_account(a)[DEBIT]:
-                return self._bal.read_bal_account(a)[DEBIT]
-            else:
-                return - self._bal.read_bal_account(a)[CREDIT]
-
-        def cred(a):
-            return self._bal.read_bal_account(a)[CREDIT]
-
-        def getProfit(value):
-            if value>0:
-                return abs(value)
-            else:
-                return 0
-        def getLoss(value):
-            if value<0:
-                return abs(value)
-            else:
-                return 0
-        external_expenses = [
-                616400, 618000, 618300, 622700, 625000, 626000, 627000]
-        charges = [("Charges d'exploitation :\nAchat de marchandises", 0),
-        ("Variation de stocks (marchandises)", 0),
-        ("Achats d'approvisionnements", deb(606400)),
-        ("Variations de stocks (approvisionnements)", 0),
-        ("Autres charges externes", sum([deb(x) for x in external_expenses])),
-        ("Impôts, taxes et versements assimilés", deb(635110)),
-        ("Rémunérations du personnel", deb(644000)),
-        ("Charges sociales", sum([deb(x) for x in [645100, 645300, 645800]])),
-        ("Dotations aux amortissements", 0),
-        ("Dotations aux provisions", 0),
-        ("Autres charges", 0),
-        ("Charges financières", deb(627800)),
-        ["Total I", 0],
-        ("Charges exceptionnelles (II)", 0),
-        ("Impôts sur les bénéfices (III)", deb(695000)),
-        ["Total des charges (I +II+ III)", 0],
-        ("Solde créditeur : bénéfice (I)", getProfit(self._bal.net_profit)),
-        ["TOTAL GENERAL", 0]]
-        charges[12][1] = sum(c[1] for c in charges[:12])
-        charges[15][1] = sum(c[1] for c in charges[12:15])
-        charges[17][1] = sum(c[1] for c in charges[15:17])
-
-        income = [("Produits d'exploitation :\nVentes de marchandises", 0),
-        ("Production vendue (biens et services)", cred(706000)),
-        ("Production stockée", 0),
-        ("Production immobilisée", 0),
-        ("Subventions d'exploitation", 0),
-        ("Autres produits", 0),
-        ("Produits financiers", 0),
-        ["Total I", 0],
-        ("dont à l’exploitation :", 0),
-        ("Produits exceptionnels (II)", 0),
-        ["Total des produits (I+II)", 0],
-        ("Solde débiteur : perte", getLoss(self._bal.net_profit)),
-        ["TOTAL GENERAL", 0],
-        ('', 0),
-        ('', 0),
-        ('', 0),
-        ('', 0),
-        ('', 0), ]
-        income[7][1] = sum(c[1] for c in income[:7])
-        income[10][1] = sum(c[1] for c in income[7:10])
-        income[12][1] = sum(c[1] for c in income[10:12])
-
-        self._charges = charges
-        self._produits = income
-        if len(charges) != len(income):
-            sys.stderr.write(_(
-                        'charges and income number lines are different!\n'))
-            sys.exit(2)
-        txt_info = _('Income statement: charges and income totals are')
-        if abs(charges[-1][1] - income[12][1]) > decimal.Decimal(epsilon):
-            sys.stderr.write(_('{0} different! charges={1}, income={2}\n'
-                        ).format(txt_info, charges[-1][1], income[12][1]))
-            sys.exit(2)
-        else:
-            sys.stdout.write(_('%s are equal!\n') % txt_info)
-
-    def get_file_name(self, year=None):
-        if not year:
-            year = self._bal._year
-        return os.path.join( config.get_accounts_dir(self._bal._orga),
-                '%s' % year, 'IncomeStatement_%s.csv' % year)
-
-    def load_previous_year(self):
-        file_income_statement = self.get_file_name(self._bal._year - 1)
-        self.prev_income_stat = []
-        if os.path.exists(file_income_statement):
-            reader = csv.reader(open(file_income_statement, 'r'),
-                    delimiter=',', quotechar='"')
-            for row in reader:
-                self.prev_income_stat.append(dict(zip([ 'charges_name',
-                    'charges_val', 'prev_charges', 'produits_name',
-                    'produits_val', 'prev_produits'], row)))
-
-    def get_prev_year(self, line, column):
-        if not self.prev_income_stat or line >= len(self.prev_income_stat):
-            return ''
-        return self.prev_income_stat[line][column]
-
-    def write_csv(self):
-        writer = csv.writer(open(self.get_file_name(), 'w'),
-                delimiter=',', quotechar='"')
-        for i in range(len(self._charges)):
-            writer.writerow([self._charges[i][0],
-                '%.2f' % round(self._charges[i][1],2),
-                self.get_prev_year(i, 'charges_val'), self._produits[i][0],
-                '%.2f' % round(self._produits[i][1],2),
-                self.get_prev_year(i, 'produits_val')])
 
 TOT_DEBT, TOT_CRED, TOT_SOLD_DEBT, TOT_SOLD_CRED = range(4)
 class Balance:
@@ -527,24 +406,14 @@ class Balance:
             self._writer.writerow(l)
 
     def profitCalculation(self):
-        gross_profit = 0
+        self.gross_profit = 0
         for a in  self._bal_accounts:
             account = a._name
             if account == 695000:
                 continue
             if (account >= 600000 and account < 700000) or account == 706000:
-                gross_profit += get_float(a._solde_credit) -\
+                self.gross_profit += get_float(a._solde_credit) -\
                                 get_float(a._solde_debit)
-        return gross_profit
-
-    def corpTaxCalculation(self, gross_profit):
-        tax = 0
-        SS_ceiling = 38120
-        if gross_profit>=0:
-            tax = gross_profit*15/100
-        if gross_profit>=SS_ceiling:
-            tax += (gross_profit-SS_ceiling)/3
-        return decimal.Decimal(str(round(tax,2)))
 
     def check_for_exercice_result(self):
         if 120000 not in [x._name for x in self._bal_accounts]:
@@ -553,12 +422,10 @@ class Balance:
                         120000, "Résultat de l'exercice", val, val, '', ''))
 
     def computCorpTax(self):
-        gross_profit = self.profitCalculation()
-        tax = self.corpTaxCalculation(gross_profit)
-
-        self.gross_profit = gross_profit
-        self.tax = tax
-        self.net_profit = gross_profit - tax
+        self.profitCalculation()
+        self.tax = IncomeStatement(None, self._orga,
+                self._year).corpTaxCalculation(self.gross_profit)
+        self.net_profit = self.gross_profit - self.tax
         self.check_for_exercice_result()
 
     def get_account(self, account):
@@ -587,7 +454,7 @@ class Balance:
         trade_marging = CA
         production_and_service = 0
         VA = trade_marging + production_and_service
-        for a in [ 606400, 616400, 618000, 618300, 622700, 625000 ]:
+        for a in [ 606400, 616400, 618000, 618300, 622700, 625000, 671200]:
             if self.read_bal_account(a)[DEBIT]:
                 VA -= self.read_bal_account(a)[DEBIT]
             else:
@@ -835,7 +702,7 @@ def diff_sides(debit, credit):
 def get_script_dir():
     return os.path.dirname(__file__)
 
-def write_GLedger(orga, year,journal_file, accounts):
+def write_GLedger(orga, year, journal_file, accounts):
     ledger_file = journal_file.split('.')[0] + '.gl.csv'
     writer = csv.writer(open(ledger_file, 'w'), delimiter=',', quotechar='"')
     columns = ['N°', 'Date', 'Comptes', 'Intitulé', 'Code opération',
