@@ -315,7 +315,12 @@ _nb_bill = %(nb_bill)s
         if not self._total_excluded_tax:
             self._total_excluded_tax = self.get_total_excluded_tax()
         return decimal.Decimal('%.3f' % round(
-                    self._total_excluded_tax * decimal.Decimal(0.196), 2))
+                    self._total_excluded_tax * decimal.Decimal(self.get_VAT_rate()), 2))
+
+    def get_VAT_rate(self):
+        if self._year<2014:
+            return 0.196
+        return 0.2
 
     def get_total_tax_incl(self):
         if not self._total_excluded_tax:
@@ -329,8 +334,9 @@ _nb_bill = %(nb_bill)s
             'last day'  : sorted(bill._dico_prestation.keys())[-1],
             'nb days'   : bill.get_nb_days(),
             'nb bill'   : '0'*(6-len(str(bill._nb_bill))) +str(bill._nb_bill),
-            'total VAT' : bill.get_total_excluded_tax(),
+            'total woVAT' : bill.get_total_excluded_tax(),
             'VAT'       : '%.2f' % bill.get_VAT(),
+            'VAT rate'  : '%.2f' % (100 * bill.get_VAT_rate()),
             'total'     : '%.2f' % bill.get_total_tax_incl(),
             'calculus'  : bill.get_calculus(),
             'amendment' : bill._amendment,
