@@ -135,6 +135,10 @@ def get_args(bill_name=False, year=False, create=False):
     parser.add_argument('-V', '--version', action='version', version='%(prog)s 0.1')
     parser.add_argument('-b', '--bench', dest='bench',
             action='store_true', default=False, help=_('private bench directory'))
+    parser.add_argument('-v', '--verbose', dest='verbose',
+            action='store_true', default=False, help=_('verbose mode'))
+    parser.add_argument('-w', '--vverbose', dest='vverbose',
+            action='store_true', default=False, help=_('more outputs'))
     parser.add_argument('-o', '--orga', dest='orga', nargs='?', default='',
             help=_('organisation name'))
     parser.add_argument('-d', '--dir', dest='account_dir', nargs='?',
