@@ -1,5 +1,8 @@
 #!/bin/bash
-bench_py="$(ls $(dirname $0)/../*/bench.py)"
+script_root=$(dirname $(realpath $0))
+app_root=$(dirname $script_root)
+export PYTHONPATH=$PYTHONPATH:$app_root
+bench_py="$(ls $app_root/*/bench.py)"
 for cmd in 'python' 'python3'; do 
     echo "$cmd:"
     $cmd "$bench_py" -o corp_ref
